summaryrefslogtreecommitdiff
path: root/nuttx/graphics
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/graphics')
-rw-r--r--nuttx/graphics/Kconfig32
-rw-r--r--nuttx/graphics/Makefile2
-rw-r--r--nuttx/graphics/README.txt26
-rw-r--r--nuttx/graphics/nxconsole/Make.defs2
-rw-r--r--nuttx/graphics/nxconsole/nxcon_driver.c8
-rw-r--r--nuttx/graphics/nxconsole/nxcon_font.c38
-rw-r--r--nuttx/graphics/nxconsole/nxcon_internal.h14
-rw-r--r--nuttx/graphics/nxconsole/nxcon_kbdin.c18
-rw-r--r--nuttx/graphics/nxconsole/nxcon_putc.c8
-rw-r--r--nuttx/graphics/nxconsole/nxcon_register.c8
-rw-r--r--nuttx/graphics/nxconsole/nxcon_scroll.c6
-rw-r--r--nuttx/graphics/nxconsole/nxcon_unregister.c4
12 files changed, 83 insertions, 83 deletions
diff --git a/nuttx/graphics/Kconfig b/nuttx/graphics/Kconfig
index 187089b54..83c62b454 100644
--- a/nuttx/graphics/Kconfig
+++ b/nuttx/graphics/Kconfig
@@ -357,17 +357,17 @@ config NXFONT_SERIF38X49B
endmenu
-menuconfig NXCONSOLE
+menuconfig NXTERM
bool "NxConsole"
default n
---help---
Enables building of the NxConsole driver.
-if NXCONSOLE
+if NXTERM
comment "NxConsole Output Text/Graphics Options"
-config NXCONSOLE_BPP
+config NXTERM_BPP
int "NxConsole BPP"
default 1 if !NX_DISABLE_1BPP
default 2 if !NX_DISABLE_2BPP
@@ -381,13 +381,13 @@ config NXCONSOLE_BPP
configuration setting must be provided to support that single pixel depth.
Default: The smallest enabled pixel depth. (see NX_DISABLE_*BPP)
-config NXCONSOLE_CURSORCHAR
+config NXTERM_CURSORCHAR
int "Character code to use as the cursor"
default 137
---help---
The bitmap code to use as the cursor. Default '_' (137)
-config NXCONSOLE_MXCHARS
+config NXTERM_MXCHARS
int "Max Characters on Display"
default 128
---help---
@@ -395,7 +395,7 @@ config NXCONSOLE_MXCHARS
that it can redraw the window. This setting determines the size of some
internal memory allocations used to hold the character data. Default: 128.
-config NXCONSOLE_CACHESIZE
+config NXTERM_CACHESIZE
int "Font Cache Size"
default 16
---help---
@@ -404,23 +404,23 @@ config NXCONSOLE_CACHESIZE
importantly (2) it preserves the font memory. Since the NX server runs on
a separate server thread, it requires that the rendered font memory persist
until the server has a chance to render the font. Unfortunately, the font
- cache would be quite large if all fonts were saved. The NXCONSOLE_CACHESIZE
+ cache would be quite large if all fonts were saved. The NXTERM_CACHESIZE
setting will control the size of the font cache (in number of glyphs). Only that
number of the most recently used glyphs will be retained. Default: 16.
NOTE: There can still be a race condition between the NxConsole driver and the
NX task. If you every see character corruption (especially when printing
- a lot of data or scrolling), then increasing the value of NXCONSOLE_CACHESIZE
+ a lot of data or scrolling), then increasing the value of NXTERM_CACHESIZE
is something that you should try. Alternatively, you can reduce the size of
MQ_MAXMSGSIZE which will force NxConsole task to pace the server task.
- NXCONSOLE_CACHESIZE should be larger than MQ_MAXMSGSIZE in any event.
+ NXTERM_CACHESIZE should be larger than MQ_MAXMSGSIZE in any event.
-config NXCONSOLE_LINESEPARATION
+config NXTERM_LINESEPARATION
int "Line Separation"
default 0
---help---
This the space (in rows) between each row of test. Default: 0
-config NXCONSOLE_NOWRAP
+config NXTERM_NOWRAP
bool "No wrap"
default n
---help---
@@ -430,7 +430,7 @@ config NXCONSOLE_NOWRAP
comment "NxConsole Input options"
-config NXCONSOLE_NXKBDIN
+config NXTERM_NXKBDIN
bool "NX KBD input"
default n
---help---
@@ -440,21 +440,21 @@ config NXCONSOLE_NXKBDIN
by window callback functions so that keyboard input *only* goes to the
top window.
-config NXCONSOLE_KBDBUFSIZE
+config NXTERM_KBDBUFSIZE
int "Keyboard Input Buffer Size"
default 16
---help---
- If NXCONSOLE_NXKBDIN is enabled, then this value may be used to
+ If NXTERM_NXKBDIN is enabled, then this value may be used to
define the size of the per-window keyboard input buffer. Default: 16
-config NXCONSOLE_NPOLLWAITERS
+config NXTERM_NPOLLWAITERS
int "Number of Poll Waiters"
default 4
---help---
The number of threads that can be waiting for read data available.
Default: 4
-endif # NXCONSOLE
+endif # NXTERM
comment "NX Multi-user only options"
diff --git a/nuttx/graphics/Makefile b/nuttx/graphics/Makefile
index b63a05312..368f236e3 100644
--- a/nuttx/graphics/Makefile
+++ b/nuttx/graphics/Makefile
@@ -59,7 +59,7 @@ DEPPATH += --dep-path nxsu
CFLAGS += ${shell $(INCDIR) $(INCDIROPT) "$(CC)" $(TOPDIR)/graphics/nxsu}
endif
-ifeq ($(CONFIG_NXCONSOLE),y)
+ifeq ($(CONFIG_NXTERM),y)
include nxconsole/Make.defs
DEPPATH += --dep-path nxconsole
CFLAGS += ${shell $(INCDIR) $(INCDIROPT) "$(CC)" $(TOPDIR)/graphics/nxconsole}
diff --git a/nuttx/graphics/README.txt b/nuttx/graphics/README.txt
index a0902546a..e025808ee 100644
--- a/nuttx/graphics/README.txt
+++ b/nuttx/graphics/README.txt
@@ -354,55 +354,55 @@ CONFIG_NXFONT_SERIF38X49B
NxConsole Configuration Settings
--------------------------------
-CONFIG_NXCONSOLE
+CONFIG_NXTERM
Enables building of the NxConsole driver.
NxConsole output text/graphics options:
-CONFIG_NXCONSOLE_BPP
+CONFIG_NXTERM_BPP
Currently, NxConsole supports only a single pixel depth. This
configuration setting must be provided to support that single pixel depth.
Default: The smallest enabled pixel depth. (see CONFIG_NX_DISABLE_*BPP)
-CONFIG_NXCONSOLE_CURSORCHAR
+CONFIG_NXTERM_CURSORCHAR
The bitmap code to use as the cursor. Default '_'
-CONFIG_NXCONSOLE_MXCHARS
+CONFIG_NXTERM_MXCHARS
NxConsole needs to remember every character written to the console so
that it can redraw the window. This setting determines the size of some
internal memory allocations used to hold the character data. Default: 128.
-CONFIG_NXCONSOLE_CACHESIZE
+CONFIG_NXTERM_CACHESIZE
NxConsole supports caching of rendered fonts. This font caching is required
for two reasons: (1) First, it improves text performance, but more
importantly (2) it preserves the font memory. Since the NX server runs on
a separate server thread, it requires that the rendered font memory persist
until the server has a chance to render the font. Unfortunately, the font
- cache would be quite large if all fonts were saved. The CONFIG_NXCONSOLE_CACHESIZE
+ cache would be quite large if all fonts were saved. The CONFIG_NXTERM_CACHESIZE
setting will control the size of the font cache (in number of glyphs). Only that
number of the most recently used glyphs will be retained. Default: 16.
NOTE: There can still be a race condition between the NxConsole driver and the
NX task. If you every see character corruption (especially when printing
- a lot of data or scrolling), then increasing the value of CONFIG_NXCONSOLE_CACHESIZE
+ a lot of data or scrolling), then increasing the value of CONFIG_NXTERM_CACHESIZE
is something that you should try. Alternatively, you can reduce the size of
CONFIG_MQ_MAXMSGSIZE which will force NxConsole task to pace the server task.
- CONFIG_NXCONSOLE_CACHESIZE should be larger than CONFIG_MQ_MAXMSGSIZE in any event.
-CONFIG_NXCONSOLE_LINESEPARATION
+ CONFIG_NXTERM_CACHESIZE should be larger than CONFIG_MQ_MAXMSGSIZE in any event.
+CONFIG_NXTERM_LINESEPARATION
This the space (in rows) between each row of test. Default: 0
-CONFIG_NXCONSOLE_NOWRAP
+CONFIG_NXTERM_NOWRAP
By default, lines will wrap when the test reaches the right hand side
of the window. This setting can be defining to change this behavior so
that the text is simply truncated until a new line is encountered.
NxConsole Input options
-CONFIG_NXCONSOLE_NXKBDIN
+CONFIG_NXTERM_NXKBDIN
Take input from the NX keyboard input callback. By default, keyboard
input is taken from stdin (/dev/console). If this option is set, then
the interface nxcon_kdbin() is enabled. That interface may be driven
by window callback functions so that keyboard input *only* goes to the
top window.
CONFIG__NXCONSOLE_KBDBUFSIZE
- If CONFIG_NXCONSOLE_NXKBDIN is enabled, then this value may be used to
+ If CONFIG_NXTERM_NXKBDIN is enabled, then this value may be used to
define the size of the per-window keyboard input buffer. Default: 16
-CONFIG_NXCONSOLE_NPOLLWAITERS
+CONFIG_NXTERM_NPOLLWAITERS
The number of threads that can be waiting for read data available.
Default: 4
diff --git a/nuttx/graphics/nxconsole/Make.defs b/nuttx/graphics/nxconsole/Make.defs
index 1d583ce89..3dc9c79a1 100644
--- a/nuttx/graphics/nxconsole/Make.defs
+++ b/nuttx/graphics/nxconsole/Make.defs
@@ -39,7 +39,7 @@ NXCON_CSRCS += nxcon_redraw.c nxcon_register.c nxcon_scroll.c
NXCON_CSRCS += nxcon_vt100.c nxcon_unregister.c nxtk_register.c
NXCON_CSRCS += nxtool_register.c
-ifeq ($(CONFIG_NXCONSOLE_NXKBDIN),y)
+ifeq ($(CONFIG_NXTERM_NXKBDIN),y)
NXCON_CSRCS += nxcon_kbdin.c
endif
diff --git a/nuttx/graphics/nxconsole/nxcon_driver.c b/nuttx/graphics/nxconsole/nxcon_driver.c
index eacf99215..0fa6f7400 100644
--- a/nuttx/graphics/nxconsole/nxcon_driver.c
+++ b/nuttx/graphics/nxconsole/nxcon_driver.c
@@ -64,7 +64,7 @@ static ssize_t nxcon_write(FAR struct file *filep, FAR const char *buffer,
****************************************************************************/
/* This is the common NX driver file operations */
-#ifdef CONFIG_NXCONSOLE_NXKBDIN
+#ifdef CONFIG_NXTERM_NXKBDIN
const struct file_operations g_nxcon_drvrops =
{
@@ -80,7 +80,7 @@ const struct file_operations g_nxcon_drvrops =
#endif
};
-#else /* CONFIG_NXCONSOLE_NXKBDIN */
+#else /* CONFIG_NXTERM_NXKBDIN */
const struct file_operations g_nxcon_drvrops =
{
@@ -96,7 +96,7 @@ const struct file_operations g_nxcon_drvrops =
#endif
};
-#endif /* CONFIG_NXCONSOLE_NXKBDIN */
+#endif /* CONFIG_NXTERM_NXKBDIN */
/****************************************************************************
* Private Data
@@ -125,7 +125,7 @@ static int nxcon_open(FAR struct file *filep)
/* Verify that the driver is opened for write-only access */
-#ifndef CONFIG_NXCONSOLE_NXKBDIN
+#ifndef CONFIG_NXTERM_NXKBDIN
if ((filep->f_oflags & O_RDOK) != 0)
{
gdbg("ERROR: Attempted open with read access\n");
diff --git a/nuttx/graphics/nxconsole/nxcon_internal.h b/nuttx/graphics/nxconsole/nxcon_internal.h
index 37bb73aec..1f66c119b 100644
--- a/nuttx/graphics/nxconsole/nxcon_internal.h
+++ b/nuttx/graphics/nxconsole/nxcon_internal.h
@@ -166,21 +166,21 @@ struct nxcon_state_s
/* Font cache data storage */
struct nxcon_bitmap_s cursor;
- struct nxcon_bitmap_s bm[CONFIG_NXCONSOLE_MXCHARS];
+ struct nxcon_bitmap_s bm[CONFIG_NXTERM_MXCHARS];
/* Glyph cache data storage */
- struct nxcon_glyph_s glyph[CONFIG_NXCONSOLE_CACHESIZE];
+ struct nxcon_glyph_s glyph[CONFIG_NXTERM_CACHESIZE];
/* Keyboard input support */
-#ifdef CONFIG_NXCONSOLE_NXKBDIN
+#ifdef CONFIG_NXTERM_NXKBDIN
sem_t waitsem; /* Supports waiting for input data */
uint8_t nwaiters; /* Number of threads waiting for data */
uint8_t head; /* rxbuffer head/input index */
uint8_t tail; /* rxbuffer tail/output index */
- uint8_t rxbuffer[CONFIG_NXCONSOLE_KBDBUFSIZE];
+ uint8_t rxbuffer[CONFIG_NXTERM_KBDBUFSIZE];
/* The following is a list if poll structures of threads waiting for
* driver events. The 'struct pollfd' reference for each open is also
@@ -188,9 +188,9 @@ struct nxcon_state_s
*/
#ifndef CONFIG_DISABLE_POLL
- struct pollfd *fds[CONFIG_NXCONSOLE_NPOLLWAITERS];
+ struct pollfd *fds[CONFIG_NXTERM_NPOLLWAITERS];
#endif
-#endif /* CONFIG_NXCONSOLE_NXKBDIN */
+#endif /* CONFIG_NXTERM_NXKBDIN */
};
/****************************************************************************
@@ -220,7 +220,7 @@ FAR struct nxcon_state_s *nxcon_register(NXCONSOLE handle,
FAR struct nxcon_window_s *wndo, FAR const struct nxcon_operations_s *ops,
int minor);
-#ifdef CONFIG_NXCONSOLE_NXKBDIN
+#ifdef CONFIG_NXTERM_NXKBDIN
ssize_t nxcon_read(FAR struct file *filep, FAR char *buffer, size_t len);
#ifndef CONFIG_DISABLE_POLL
int nxcon_poll(FAR struct file *filep, FAR struct pollfd *fds, bool setup);
diff --git a/nuttx/graphics/nxconsole/nxcon_putc.c b/nuttx/graphics/nxconsole/nxcon_putc.c
index d51d79c79..f612b2eb3 100644
--- a/nuttx/graphics/nxconsole/nxcon_putc.c
+++ b/nuttx/graphics/nxconsole/nxcon_putc.c
@@ -99,7 +99,7 @@ void nxcon_putc(FAR struct nxcon_state_s *priv, uint8_t ch)
if (priv->fpos.x + priv->fwidth > priv->wndo.wsize.w)
{
-#ifndef CONFIG_NXCONSOLE_NOWRAP
+#ifndef CONFIG_NXTERM_NOWRAP
/* No.. move to the next line */
nxcon_newline(priv);
@@ -132,7 +132,7 @@ void nxcon_putc(FAR struct nxcon_state_s *priv, uint8_t ch)
/* Check if we need to scroll up */
- lineheight = (priv->fheight + CONFIG_NXCONSOLE_LINESEPARATION);
+ lineheight = (priv->fheight + CONFIG_NXTERM_LINESEPARATION);
while (priv->fpos.y >= priv->wndo.wsize.h - lineheight)
{
nxcon_scroll(priv, lineheight);
@@ -165,7 +165,7 @@ void nxcon_showcursor(FAR struct nxcon_state_s *priv)
if (priv->fpos.x + priv->fwidth > priv->wndo.wsize.w)
{
-#ifndef CONFIG_NXCONSOLE_NOWRAP
+#ifndef CONFIG_NXTERM_NOWRAP
/* No.. move to the next line */
nxcon_newline(priv);
@@ -176,7 +176,7 @@ void nxcon_showcursor(FAR struct nxcon_state_s *priv)
/* Check if we need to scroll up */
- lineheight = (priv->fheight + CONFIG_NXCONSOLE_LINESEPARATION);
+ lineheight = (priv->fheight + CONFIG_NXTERM_LINESEPARATION);
while (priv->fpos.y >= priv->wndo.wsize.h - lineheight)
{
nxcon_scroll(priv, lineheight);
diff --git a/nuttx/graphics/nxconsole/nxcon_register.c b/nuttx/graphics/nxconsole/nxcon_register.c
index 33f95520b..67859922f 100644
--- a/nuttx/graphics/nxconsole/nxcon_register.c
+++ b/nuttx/graphics/nxconsole/nxcon_register.c
@@ -103,7 +103,7 @@ FAR struct nxcon_state_s *
priv->holder = NO_HOLDER;
#endif
-#ifdef CONFIG_NXCONSOLE_NXKBDIN
+#ifdef CONFIG_NXTERM_NXKBDIN
sem_init(&priv->waitsem, 0, 0);
#endif
@@ -129,11 +129,11 @@ FAR struct nxcon_state_s *
/* Set up the text cache */
- priv->maxchars = CONFIG_NXCONSOLE_MXCHARS;
+ priv->maxchars = CONFIG_NXTERM_MXCHARS;
/* Set up the font glyph bitmap cache */
- priv->maxglyphs = CONFIG_NXCONSOLE_CACHESIZE;
+ priv->maxglyphs = CONFIG_NXTERM_CACHESIZE;
/* Set the initial display position */
@@ -141,7 +141,7 @@ FAR struct nxcon_state_s *
/* Show the cursor */
- priv->cursor.code = CONFIG_NXCONSOLE_CURSORCHAR;
+ priv->cursor.code = CONFIG_NXTERM_CURSORCHAR;
nxcon_showcursor(priv);
/* Register the driver */
diff --git a/nuttx/graphics/nxconsole/nxcon_scroll.c b/nuttx/graphics/nxconsole/nxcon_scroll.c
index 3276fc650..7c645976c 100644
--- a/nuttx/graphics/nxconsole/nxcon_scroll.c
+++ b/nuttx/graphics/nxconsole/nxcon_scroll.c
@@ -106,7 +106,7 @@ static inline void nxcon_movedisplay(FAR struct nxcon_state_s *priv,
rect.pt1.x = 0;
rect.pt2.x = priv->wndo.wsize.w - 1;
- for (row = CONFIG_NXCONSOLE_LINESEPARATION; row < bottom; row += scrollheight)
+ for (row = CONFIG_NXTERM_LINESEPARATION; row < bottom; row += scrollheight)
{
/* Create a bounding box the size of one row of characters */
@@ -154,7 +154,7 @@ static inline void nxcon_movedisplay(FAR struct nxcon_state_s *priv,
/* Add the line separation value to the scroll height */
- scrollheight += CONFIG_NXCONSOLE_LINESEPARATION;
+ scrollheight += CONFIG_NXTERM_LINESEPARATION;
/* Move the display in the range of 0-height up one scrollheight. The
* line at the bottom will be reset to the background color automatically.
@@ -213,7 +213,7 @@ void nxcon_scroll(FAR struct nxcon_state_s *priv, int scrollheight)
/* Has any part of this character scrolled off the screen? */
- if (bm->pos.y < scrollheight + CONFIG_NXCONSOLE_LINESEPARATION)
+ if (bm->pos.y < scrollheight + CONFIG_NXTERM_LINESEPARATION)
{
/* Yes... Delete the character by moving all of the data */
diff --git a/nuttx/graphics/nxconsole/nxcon_unregister.c b/nuttx/graphics/nxconsole/nxcon_unregister.c
index d0dc97b97..2ebfdf7ec 100644
--- a/nuttx/graphics/nxconsole/nxcon_unregister.c
+++ b/nuttx/graphics/nxconsole/nxcon_unregister.c
@@ -97,13 +97,13 @@ void nxcon_unregister(NXCONSOLE handle)
priv = (FAR struct nxcon_state_s *)handle;
sem_destroy(&priv->exclsem);
-#ifdef CONFIG_NXCONSOLE_NXKBDIN
+#ifdef CONFIG_NXTERM_NXKBDIN
sem_destroy(&priv->waitsem);
#endif
/* Free all allocated glyph bitmap */
- for (i = 0; i < CONFIG_NXCONSOLE_CACHESIZE; i++)
+ for (i = 0; i < CONFIG_NXTERM_CACHESIZE; i++)
{
FAR struct nxcon_glyph_s *glyph = &priv->glyph[i];
if (glyph->bitmap)
diff --git a/nuttx/graphics/nxconsole/nxcon_font.c b/nuttx/graphics/nxconsole/nxcon_font.c
index a9afa0c14..5d44af36a 100644
--- a/nuttx/graphics/nxconsole/nxcon_font.c
+++ b/nuttx/graphics/nxconsole/nxcon_font.c
@@ -56,22 +56,22 @@
* pixel depths that are not directly addressable (1,2,4, and 24).
*/
-#if CONFIG_NXCONSOLE_BPP == 1
+#if CONFIG_NXTERM_BPP == 1
# define RENDERER nxf_convert_1bpp
-#elif CONFIG_NXCONSOLE_BPP == 2
+#elif CONFIG_NXTERM_BPP == 2
# define RENDERER nxf_convert_2bpp
-#elif CONFIG_NXCONSOLE_BPP == 4
+#elif CONFIG_NXTERM_BPP == 4
# define RENDERER nxf_convert_4bpp
-#elif CONFIG_NXCONSOLE_BPP == 8
+#elif CONFIG_NXTERM_BPP == 8
# define RENDERER nxf_convert_8bpp
-#elif CONFIG_NXCONSOLE_BPP == 16
+#elif CONFIG_NXTERM_BPP == 16
# define RENDERER nxf_convert_16bpp
-#elif CONFIG_NXCONSOLE_BPP == 24
+#elif CONFIG_NXTERM_BPP == 24
# define RENDERER nxf_convert_24bpp
-#elif CONFIG_NXCONSOLE_BPP == 32
+#elif CONFIG_NXTERM_BPP == 32
# define RENDERER nxf_convert_32bpp
#else
-# error "Unsupported CONFIG_NXCONSOLE_BPP"
+# error "Unsupported CONFIG_NXTERM_BPP"
#endif
/****************************************************************************
@@ -219,7 +219,7 @@ nxcon_renderglyph(FAR struct nxcon_state_s *priv,
{
FAR struct nxcon_glyph_s *glyph = NULL;
FAR nxgl_mxpixel_t *ptr;
-#if CONFIG_NXCONSOLE_BPP < 8
+#if CONFIG_NXTERM_BPP < 8
nxgl_mxpixel_t pixel;
#endif
int bmsize;
@@ -239,7 +239,7 @@ nxcon_renderglyph(FAR struct nxcon_state_s *priv,
/* Get the physical width of the glyph in bytes */
- glyph->stride = (glyph->width * CONFIG_NXCONSOLE_BPP + 7) / 8;
+ glyph->stride = (glyph->width * CONFIG_NXTERM_BPP + 7) / 8;
/* Allocate memory to hold the glyph with its offsets */
@@ -256,10 +256,10 @@ nxcon_renderglyph(FAR struct nxcon_state_s *priv,
* differing BPP's as well.
*/
-#if CONFIG_NXCONSOLE_BPP < 8
+#if CONFIG_NXTERM_BPP < 8
pixel = priv->wndo.wcolor[0];
-# if CONFIG_NXCONSOLE_BPP == 1
+# if CONFIG_NXTERM_BPP == 1
/* Pack 1-bit pixels into a 2-bits */
@@ -267,7 +267,7 @@ nxcon_renderglyph(FAR struct nxcon_state_s *priv,
pixel = (pixel) << 1 | pixel;
# endif
-# if CONFIG_NXCONSOLE_BPP < 4
+# if CONFIG_NXTERM_BPP < 4
/* Pack 2-bit pixels into a nibble */
@@ -292,10 +292,10 @@ nxcon_renderglyph(FAR struct nxcon_state_s *priv,
}
}
-#elif CONFIG_NXCONSOLE_BPP == 24
+#elif CONFIG_NXTERM_BPP == 24
# error "Additional logic is needed here for 24bpp support"
-#else /* CONFIG_NXCONSOLE_BPP = {8,16,32} */
+#else /* CONFIG_NXTERM_BPP = {8,16,32} */
ptr = (FAR nxgl_mxpixel_t *)glyph->bitmap;
for (row = 0; row < glyph->height; row++)
@@ -538,9 +538,9 @@ void nxcon_home(FAR struct nxcon_state_s *priv)
priv->fpos.x = priv->spwidth;
- /* And CONFIG_NXCONSOLE_LINESEPARATION lines from the top */
+ /* And CONFIG_NXTERM_LINESEPARATION lines from the top */
- priv->fpos.y = CONFIG_NXCONSOLE_LINESEPARATION;
+ priv->fpos.y = CONFIG_NXTERM_LINESEPARATION;
}
/****************************************************************************
@@ -557,9 +557,9 @@ void nxcon_newline(FAR struct nxcon_state_s *priv)
priv->fpos.x = priv->spwidth;
- /* Linefeed: Down the max font height + CONFIG_NXCONSOLE_LINESEPARATION */
+ /* Linefeed: Down the max font height + CONFIG_NXTERM_LINESEPARATION */
- priv->fpos.y += (priv->fheight + CONFIG_NXCONSOLE_LINESEPARATION);
+ priv->fpos.y += (priv->fheight + CONFIG_NXTERM_LINESEPARATION);
}
/****************************************************************************
diff --git a/nuttx/graphics/nxconsole/nxcon_kbdin.c b/nuttx/graphics/nxconsole/nxcon_kbdin.c
index cf2d9cfcf..fa7990a71 100644
--- a/nuttx/graphics/nxconsole/nxcon_kbdin.c
+++ b/nuttx/graphics/nxconsole/nxcon_kbdin.c
@@ -48,7 +48,7 @@
#include "nxcon_internal.h"
-#ifdef CONFIG_NXCONSOLE_NXKBDIN
+#ifdef CONFIG_NXTERM_NXKBDIN
/****************************************************************************
* Pre-processor Definitions
@@ -79,7 +79,7 @@ static void nxcon_pollnotify(FAR struct nxcon_state_s *priv, pollevent_t eventse
/* This function may be called from an interrupt handler */
- for (i = 0; i < CONFIG_NXCONSOLE_NPOLLWAITERS; i++)
+ for (i = 0; i < CONFIG_NXTERM_NPOLLWAITERS; i++)
{
flags = irqsave();
fds = priv->fds[i];
@@ -231,7 +231,7 @@ ssize_t nxcon_read(FAR struct file *filep, FAR char *buffer, size_t len)
/* Increment the tail index and re-enable interrupts */
- if (++priv->tail >= CONFIG_NXCONSOLE_KBDBUFSIZE)
+ if (++priv->tail >= CONFIG_NXTERM_KBDBUFSIZE)
{
priv->tail = 0;
}
@@ -298,7 +298,7 @@ int nxcon_poll(FAR struct file *filep, FAR struct pollfd *fds, bool setup)
* slot for the poll structure reference
*/
- for (i = 0; i < CONFIG_NXCONSOLE_NPOLLWAITERS; i++)
+ for (i = 0; i < CONFIG_NXTERM_NPOLLWAITERS; i++)
{
/* Find an available slot */
@@ -312,7 +312,7 @@ int nxcon_poll(FAR struct file *filep, FAR struct pollfd *fds, bool setup)
}
}
- if (i >= CONFIG_NXCONSOLE_NPOLLWAITERS)
+ if (i >= CONFIG_NXTERM_NPOLLWAITERS)
{
gdbg("ERROR: Too many poll waiters\n");
@@ -378,10 +378,10 @@ errout:
* this function. This function will buffer the keyboard data and makE
* it available to the NxConsole as stdin.
*
* If CONFIG_NXCONSOLE_NXKBDIN is not selected, then the NxConsole will
* receive its input from stdin (/dev/console). This works great but
* cannot be shared between different windows. Chaos will ensue if you
* try to support multiple NxConsole windows without CONFIG_NXCONSOLE_NXKBDIN
*
* Input Parameters:
* handle - A handle previously returned by nx_register, nxtk_register, or
@@ -438,7 +438,7 @@ void nxcon_kbdin(NXCONSOLE handle, FAR const uint8_t *buffer, uint8_t buflen)
*/
nexthead = priv->head + 1;
- if (nexthead >= CONFIG_NXCONSOLE_KBDBUFSIZE)
+ if (nexthead >= CONFIG_NXTERM_KBDBUFSIZE)
{
nexthead = 0;
}
@@ -486,4 +486,4 @@ void nxcon_kbdin(NXCONSOLE handle, FAR const uint8_t *buffer, uint8_t buflen)
nxcon_sempost(priv);
}
-#endif /* CONFIG_NXCONSOLE_NXKBDIN */
+#endif /* CONFIG_NXTERM_NXKBDIN */
@@ -378,10 +378,10 @@ errout:
* it available to the NxConsole as stdin.
*
- * If CONFIG_NXCONSOLE_NXKBDIN is not selected, then the NxConsole will
+ * If CONFIG_NXTERM_NXKBDIN is not selected, then the NxConsole will
* receive its input from stdin (/dev/console). This works great but
* cannot be shared between different windows. Chaos will ensue if you
@@ -378,10 +378,10 @@ errout:
* receive its input from stdin (/dev/console). This works great but
* cannot be shared between different windows. Chaos will ensue if you
- * try to support multiple NxConsole windows without CONFIG_NXCONSOLE_NXKBDIN
+ * try to support multiple NxConsole windows without CONFIG_NXTERM_NXKBDIN
*
* Input Parameters: